==> openshift-model-operatorhub-5.0.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StrategyDeploymentPermissionsFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.model.rbac.PolicyRule;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface StrategyDeploymentPermissionsFluent<A extends StrategyDeploymentPermissionsFluent<A>> extends Fluent<A> {


    public A addToRules(int index,PolicyRule item);
    public A setToRules(int index,PolicyRule item);
    public A addToRules(PolicyRule... items);
    public A addAllToRules(Collection<PolicyRule> items);
    public A removeFromRules(PolicyRule... items);
    public A removeAllFromRules(Collection<PolicyRule> items);
    public List<PolicyRule> getRules();
    public PolicyRule getRule(int index);
    public PolicyRule getFirstRule();
    public PolicyRule getLastRule();
    public PolicyRule getMatchingRule(Predicate<PolicyRule> predicate);
    public Boolean hasMatchingRule(Predicate<PolicyRule> predicate);
    public A withRules(List<PolicyRule> rules);
    public A withRules(PolicyRule... rules);
    public Boolean hasRules();
    public String getServiceAccountName();
    public A withServiceAccountName(String serviceAccountName);
    public Boolean hasServiceAccountName();
    public A withNewServiceAccountName(String arg1);
    public A withNewServiceAccountName(StringBuilder arg1);
    public A withNewServiceAccountName(StringBuffer arg1);
}

==> openshift-model-operatorhub-5.3.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StrategyDeploymentPermissionsFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.model.rbac.PolicyRule;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface StrategyDeploymentPermissionsFluent<A extends StrategyDeploymentPermissionsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public A addToRules(int index,PolicyRule item);
    public A setToRules(int index,PolicyRule item);
    public A addToRules(PolicyRule... items);
    public A addAllToRules(Collection<PolicyRule> items);
    public A removeFromRules(PolicyRule... items);
    public A removeAllFromRules(Collection<PolicyRule> items);
    public List<PolicyRule> getRules();
    public PolicyRule getRule(int index);
    public PolicyRule getFirstRule();
    public PolicyRule getLastRule();
    public PolicyRule getMatchingRule(Predicate<PolicyRule> predicate);
    public Boolean hasMatchingRule(Predicate<PolicyRule> predicate);
    public A withRules(List<PolicyRule> rules);
    public A withRules(PolicyRule... rules);
    public Boolean hasRules();
    public String getServiceAccountName();
    public A withServiceAccountName(String serviceAccountName);
    public Boolean hasServiceAccountName();
    public A withNewServiceAccountName(StringBuilder arg1);
    public A withNewServiceAccountName(int[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(char[] arg1);
    public A withNewServiceAccountName(StringBuffer arg1);
    public A withNewServiceAccountName(byte[] arg1,int arg2);
    public A withNewServiceAccountName(byte[] arg1);
    public A withNewServiceAccountName(char[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewServiceAccountName(String arg1);
}
